@@ -5,9 +5,16 @@ use DateTime;
 use DateTime::Format::Strptime;
 use base qw(Class::Accessor::Fast);
 
-__PACKAGE__->mk_accessors(qw(programme start stop title
-description channel_number station_name input_source repeats quality
-enabled));
+__PACKAGE__->mk_accessors(
+  qw(programme start stop title
+    description channel_number station_name input_source repeats quality
+    enabled id)
+);
+
+sub delete {
+  my $self = shift;
+  $self->programme->delete;
+}
 
 sub duration {
   my $self = shift;
@@ -17,21 +24,21 @@ sub duration {
 sub record {
   my $self = shift;
 
-  my $start = $self->start;
-  my $stop = $self->stop;
-  my $title = $self->title;
-  my $description = $self->description || "";
+  my $start          = $self->start;
+  my $stop           = $self->stop;
+  my $title          = $self->title;
+  my $description    = $self->description || "";
   my $channel_number = $self->channel_number;
-  my $duration = ($stop->epoch - $start->epoch);
+  my $duration       = ($stop->epoch - $start->epoch);
 
   my $eyetv = Mac::Glue->new('EyeTV');
   $eyetv->make(
-    new => 'program',
+    new             => 'program',
     with_properties => {
-      'start time' => $start->epoch,
-      duration => $duration,
-      title => $title,
-      description => $description,
+      'start time'     => $start->epoch,
+      duration         => $duration,
+      title            => $title,
+      description      => $description,
       'channel number' => $channel_number,
     },
   );
@@ -51,7 +58,7 @@ Mac::EyeTV::Programme - An EyeTV programme
   my $eyetv = Mac::EyeTV->new();
 
   # Examine existing programmes
-  foreach my $programme ($eyetv->programs) {
+  foreach my $programme ($eyetv->programmes) {
     my $start       = $programme->start;
     my $stop        = $programme->stop;
     my $title       = $programme->title;
@@ -60,7 +67,7 @@ Mac::EyeTV::Programme - An EyeTV programme
     print "$title $start - $stop ($description)\n";
   }
 
-  # Record a new program
+  # Record a new programme
   my $programme = Mac::EyeTV::Programme->new;
   $programme->start($start_dt);
   $programme->stop($stop_dt);
@@ -68,10 +75,13 @@ Mac::EyeTV::Programme - An EyeTV programme
   $programme->description($description);
   $programme->channel_number($channel_number);
   $programme->record;
+  
+  # Delete an existing programme
+  $programme->delete;
 
 =head1 DESCRIPTION
 
-This module represents an EyeTV program. The programs() method in
+This module represents an EyeTV program. The programmes() method in
 Mac::EyeTV returns a list of Mac::EyeTV::Programme objects which
 represent the existing and future programs.
 
@@ -83,15 +93,21 @@ This is the constructor, which takes no arguments:
 
   my $eyetv = Mac::EyeTV->new();
 
+=head2 delete
+
+The delete() method deletes the programme:
+
+  $programme->delete;
+
 =head2 description
 
-The description() method returns the description of the program:
+The description() method returns the description of the programme:
 
   my $description = $programme->description;
 
 =head2 duration
 
-The duration() method returns the duration of the program (as a
+The duration() method returns the duration of the programme (as a
 DateTime::Duration object):
 
   my $duration = $programme->duration;
@@ -111,21 +127,21 @@ The record method schedules a new recording:
 
 =head2 start
 
-The start method returns when the program starts (as a DateTime
+The start method returns when the programme starts (as a DateTime
 object):
 
   my $start = $programme->start;
 
 =head2 stop
 
-The stop method returns when the program stops (as a DateTime
+The stop method returns when the programme stops (as a DateTime
 object):
 
   my $stop = $programme->stop;
 
 =head2 title
 
-The title() method returns the title of the program:
+The title() method returns the title of the programme:
 
   my $title = $programme->title;
 
@@ -135,7 +151,7 @@ Leon Brocard <acme@astray.com>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2004, Leon Brocard
+Copyright (C) 2004-5, Leon Brocard
 
 This module is free software; you can redistribute it or modify it
 under the same terms as Perl itself.
